Lang.prototype.pack.zh = {
	"token": {
		"script running report": "脚本运行报告",
        "Contact Us": "联系我们",
		"I am sorry, this log file is empty!": "你没有眼花，这个Log文件就是一片空白",
		"Test Case": "测试用例",
		"[Passed]": "[运行成功]",
		"[Failed]": "[运行失败]",
		"Author:": "作者：",
		"Author: Anonymous": "作者：佚名",
		"Assert: Test Steps Summary": "Assert 测试点汇总",
		"Test step": "测试点",
		"Expected result:": "预期结果：",
		"No record information found.": "暂无设备录屏信息",
		"Target object": "目标图片",
		"Runtime screenshot": "运行时屏幕截图",
		"Matching confidence:": "匹配度：",
		"Execution finished successfully": "执行成功",
		"Execution failed": "执行失败",
		"Steps navigation": "步骤导航",
		"Related information": "相关信息",
		"Touch": "点击",
		"Swipe": "滑动",
		"Wait": "等待目标出现",
		"Exists": "根据图片是否存在选择分支",
		"Text": "输入",
		"Keyevent": "按键",
		"Sleep": "等待",
		"Server call": "调用服务器方法",
		"Assert exists": "断言目标存在",
		"Assert not exists": "断言目标不存在",
		"Snapshot": "截图",
		"Assert equal": "断言相等",
		"Assert not equal": "断言不相等",
		"Title": "标题",
		"Description:": "描述：",
		"Time:": "时间："
	}
};